aboutsummaryrefslogtreecommitdiffstats
path: root/gtk/capture_dlg.h
diff options
context:
space:
mode:
authorUlf Lamping <ulf.lamping@web.de>2005-04-16 20:08:00 +0000
committerUlf Lamping <ulf.lamping@web.de>2005-04-16 20:08:00 +0000
commit83dc83abd8dca40a7ee13b97855dbda4f01737ec (patch)
tree3bac5a359bfb27c7a0c59f4cd0b7ed229ff1208e /gtk/capture_dlg.h
parent708dae1a17665c8dd4ccac770e4b509dc09fc0b1 (diff)
rename capture_clear() to capture_restart()
statusbar update should work now even in capture error case svn path=/trunk/; revision=14105
Diffstat (limited to 'gtk/capture_dlg.h')
-rw-r--r--gtk/capture_dlg.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/gtk/capture_dlg.h b/gtk/capture_dlg.h
index 70921784f2..2d76a848bd 100644
--- a/gtk/capture_dlg.h
+++ b/gtk/capture_dlg.h
@@ -52,12 +52,12 @@ void capture_start_cb(GtkWidget *widget, gpointer data);
*/
void capture_stop_cb(GtkWidget *widget, gpointer data);
/** User requested capture clear by menu or toolbar.
*
* @param widget parent widget (unused)
* @param data unused
*/
-void capture_clear_cb(GtkWidget *widget, gpointer data);
+void capture_restart_cb(GtkWidget *widget, gpointer data);
/** Create the "Capture Options" dialog box.
*/
@@ -52,12 +52,12 @@ void capture_start_cb(GtkWidget *widget, gpointer data);
*/
void capture_stop_cb(GtkWidget *widget, gpointer data);
-/** User requested capture clear by menu or toolbar.
+/** User requested capture restart by menu or toolbar.
*
* @param widget parent widget (unused)